function [rs, p, varargout]=test_spearman(data,alfa)
% funkce provadi test zalozeny na Spearmanove koeficientu
% vstupni parametry:
% data - vektor realizaci
% alfa - zvolena hladina vyznamnosti
% vystupni parametry:
% rs   - hodnota testove tatistiky
% p    - p-hodnota testu
% H    - hypoteza (H = 1: zamitnuti H0,
%                  H = 0: nezamitnuti H0,
%                  H = -1: nelze rozhodnout (napr. alfa neni zadana)
% moznosti zadani:
% [rs, p] = test_spearman(data)
% [rs, p, H] = test_spearman(data, alfa)

y = [1:length(data)]';
R = tiedrank(data);
[rs, p] = corrcoef(y,R);
rs = rs(1,2);
p = p(1,2);
if exist('alfa','var')
    if (p<=alfa)
        H = 1;
    else
        H = 0;
    end
    varargout{1}=H;
else
    varargout{1}=-1;
end